@@ -13,20 +13,24 @@ sub _clean_eval {
 use warnings;
 
 BEGIN {
-	*HAS_LEXICAL_SUBS = ( $] >= 5.018 ) ? sub() { !!1 } : sub() { !!0 };
+	*HAS_LEXICAL_SUBS = ( $] >= 5.018 ) ? sub () { !!1 } : sub () { !!0 };
+	*NICE_PROTOTYPES  = ( $] >= 5.014 ) ? sub () { !!1 } : sub () { !!0 };
 }
 
-{
-	# this is unused now and will be removed in a future version of Eval::TypeTiny
-	my $hlv;
-	
-	sub HAS_LEXICAL_VARS () {
-		$hlv = !!eval {
-			require Devel::LexAlias;
-			exists( &Devel::LexAlias::lexalias );
-		} unless defined $hlv;
-		$hlv;
+sub _pick_alternative {
+	my $ok = 0;
+	while ( @_ ) {
+		my ( $type, $condition, $result ) = splice @_, 0, 3;
+		if ( $type eq 'needs' ) {
+			++$ok if eval "require $condition; 1";
+		}
+		elsif ( $type eq 'if' ) {
+			++$ok if $condition;
+		}
+		next unless $ok;
+		return ref( $result ) eq 'CODE' ? $result->() : ref( $result ) eq 'SCALAR' ? eval( $$result ) : $result;
 	}
+	return;
 }
 
 {
@@ -40,12 +44,12 @@ BEGIN {
 	#<<<
 	# uncoverable subroutine
 	sub ALIAS_IMPLEMENTATION () {
-		$implementation ||= do {
-			do { $] ge '5.022' }              ? IMPLEMENTATION_NATIVE :
-			eval { require Devel::LexAlias }  ? IMPLEMENTATION_DEVEL_LEXALIAS :
-			eval { require PadWalker }        ? IMPLEMENTATION_PADWALKER :
-			IMPLEMENTATION_TIE;
-		};
+		$implementation ||= _pick_alternative(
+			if    => ( $] ge '5.022' ) => IMPLEMENTATION_NATIVE,
+			needs => 'Devel::LexAlias' => IMPLEMENTATION_DEVEL_LEXALIAS,
+			needs => 'PadWalker'       => IMPLEMENTATION_PADWALKER,
+			if    => !!1               => IMPLEMENTATION_TIE,
+		);
 	}
 	#>>>
 	
@@ -59,12 +63,13 @@ BEGIN {
 }
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '1.016008';
+our $VERSION   = '2.008003';
 our @EXPORT    = qw( eval_closure );
 our @EXPORT_OK = qw(
 	HAS_LEXICAL_SUBS HAS_LEXICAL_VARS ALIAS_IMPLEMENTATION
 	IMPLEMENTATION_DEVEL_LEXALIAS IMPLEMENTATION_PADWALKER
 	IMPLEMENTATION_NATIVE IMPLEMENTATION_TIE
+	set_subname type_to_coderef NICE_PROTOTYPES
 );
 
 $VERSION =~ tr/_//d;
@@ -84,6 +89,94 @@ sub import {
 	return $class->$next( $opts, @_ );
 } #/ sub import
 
+{
+	my $subname;
+	my %already;    # prevent renaming established functions
+	sub set_subname ($$) {
+		$subname = _pick_alternative(
+			needs => 'Sub::Util' => \ q{ \&Sub::Util::set_subname },
+			needs => 'Sub::Name' => \ q{ \&Sub::Name::subname     },
+			if    => !!1         => 0,
+		) unless defined $subname;
+		$subname and !$already{$_[1]}++ and return &$subname;
+		$_[1];
+	} #/ sub set_subname ($$)
+}
+
+sub type_to_coderef {
+	my ( $type, %args ) = @_;
+	my $post_method = $args{post_method} || q();
+	
+	my ( $coderef, $qualified_name );
+	
+	if ( ! defined $type ) {
+		my $library = $args{type_library};
+		my $name    = $args{type_name};
+		
+		$qualified_name = "$library\::$name";
+		$coderef = sub (;@) {
+			my $params;
+			$params = shift if ref( $_[0] ) eq "ARRAY";
+			
+			$type ||= do {
+				$library->can( 'get_type' )
+					or require Error::TypeTiny
+					&& Error::TypeTiny::croak( "Expected $library to be a type library, but it doesn't seem to be" );
+				$library->get_type( $name );
+			};
+			
+			my $t;
+			if ( $type ) {
+				$t = $params ? $type->parameterize( @$params ) : $type;
+				$t = $t->$post_method if $post_method;
+			}
+			else {
+				require Error::TypeTiny && Error::TypeTiny::croak( "Cannot parameterize a non-existant type" )
+					if $params;
+				require Type::Tiny::_DeclaredType;
+				$t = Type::Tiny::_DeclaredType->new( library => $library, name => $name );
+			}
+			
+			@_ && wantarray ? return ( $t, @_ ) : return $t;
+		};
+		
+		require Scalar::Util && &Scalar::Util::set_prototype( $coderef, ';$' )
+			if Eval::TypeTiny::NICE_PROTOTYPES;
+	}
+	else {
+	
+		#<<<
+		my $source = $type->is_parameterizable ?
+			sprintf(
+				q{
+					sub (%s) {
+						if (ref($_[0]) eq 'Type::Tiny::_HalfOp') {
+							my $complete_type = shift->complete($type);
+							@_ && wantarray ? return($complete_type, @_) : return $complete_type;
+						}
+						my $params; $params = shift if ref($_[0]) eq q(ARRAY);
+						my $t = $params ? $type->parameterize(@$params) : $type;
+						@_ && wantarray ? return($t%s, @_) : return $t%s;
+					}
+				},
+				NICE_PROTOTYPES ? q(;$) : q(;@),
+				$post_method,
+				$post_method,
+			) :
+			sprintf( q{ sub () { $type%s if $] } }, $post_method );
+		#>>>
+		
+		$qualified_name = $type->qualified_name;
+		$coderef = eval_closure(
+			source      => $source,
+			description => $args{description} || sprintf( "exportable function '%s'", $qualified_name ),
+			environment => { '$type' => \$type },
+		);
+	}
+	
+	$args{anonymous} ? $coderef : set_subname( $qualified_name, $coderef );
+}
+
 sub eval_closure {
 	my ( %args ) = @_;
 	my $src =
@@ -340,8 +433,8 @@ Perl code, and hashrefs of variables to close over.
 
 =head2 Functions
 
-This module exports one function, which works much like the similarly named
-function from L<Eval::Closure>:
+By default this module exports one function, which works much like the
+similarly named function from L<Eval::Closure>:
 
 =over
 
@@ -349,6 +442,41 @@ function from L<Eval::Closure>:
 
 =back
 
+Other functions can be imported on request:
+
+=over
+
+=item C<< set_subname( $fully_qualified_name, $coderef ) >>
+
+Works like the similarly named function from L<Sub::Util>, but will
+fallback to doing nothing if neither L<Sub::Util> nor L<Sub::Name> are
+available. Also will cowardly refuse the set the name of a coderef
+a second time if it's already named it.
+
+=item C<< type_to_coderef( $type, %options ) >>
+
+Turns a L<Type::Tiny> object into a coderef, suitable for installing
+into a symbol table to create a function like C<ArrayRef> or C<Int>.
+(Actually should work for any object which provides C<is_parameterizable>,
+C<parameterize>, and C<qualified_name> methods, such as L<Type::Coercion>.)
+
+C<< $options{post_method} >> can be a string of Perl indicating a
+method to call on the type constraint before returning it. For
+example C<< '->moose_type' >>.
+
+C<< $options{description} >> can be a description of the coderef which
+may be shown in stack traces, etc.
+
+The coderef will be named using C<set_subname> unless
+C<< $options{anonymous} >> is true.
+
+If C<< $type >> is undef, then it is assumed that the type constraint
+hasn't been defined yet but will later, yet you still want a function now.
+C<< $options{type_library} >> and C<< $options{type_name} >> will be
+used to find the type constraint when the function gets called.
+
+=back
+
 =head2 Constants
 
 The following constants may be exported, but are not by default.
@@ -364,7 +492,7 @@ Boolean indicating whether Eval::TypeTiny has support for lexical subs.
 
 Returns a string indicating what implementation of C<< alias => 1 >> is
 being used. Eval::TypeTiny will automatically choose the best implementation.
-This constant can be matched against the C<< IMPLEMENTAION_* >> constants.
+This constant can be matched against the C<< IMPLEMENTATION_* >> constants.
 
 =item C<< IMPLEMENTATION_NATIVE >>
 
@@ -390,6 +518,16 @@ trying to alias already-tied variables, but it's the only way to implement
 C<< alias => 1 >> without a recent version of Perl or one of the two optional
 modules mentioned above.
 
+=item C<< NICE_PROTOTYPES >>
+
+If this is true, then type_to_coderef will give parameterizable type
+constraints the slightly nicer prototype of C<< (;$) >> instead of the
+default C<< (;@) >>. This allows constructs like:
+
+   ArrayRef[Int] | HashRef[Int]
+
+... to "just work".
+
 =back
 
 =head1 EVALUATION ENVIRONMENT
@@ -435,7 +573,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014, 2017-2022 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2017-2025 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
