@@ -6,7 +6,7 @@ use warnings;
 
 BEGIN {
 	$Type::Tiny::Duck::AUTHORITY = 'cpan:TOBYINK';
-	$Type::Tiny::Duck::VERSION   = '2.000001';
+	$Type::Tiny::Duck::VERSION   = '2.008003';
 }
 
 $Type::Tiny::Duck::VERSION =~ tr/_//d;
@@ -15,7 +15,6 @@ use Scalar::Util qw< blessed >;
 
 sub _croak ($;@) { require Error::TypeTiny; goto \&Error::TypeTiny::croak }
 
-
 use Exporter::Tiny 1.004001 ();
 use Type::Tiny::ConstrainedObject ();
 our @ISA = qw( Type::Tiny::ConstrainedObject Exporter::Tiny );
@@ -58,6 +57,11 @@ sub new {
 	return $proto->SUPER::new( %opts );
 } #/ sub new
 
+sub _lockdown {
+	my ( $self, $callback ) = @_;
+	$callback->( $self->{methods} );
+}
+
 sub methods { $_[0]{methods} }
 sub inlined { $_[0]{inlined} ||= $_[0]->_build_inlined }
 
@@ -177,6 +181,75 @@ __END__
 
 Type::Tiny::Duck - type constraints based on the "can" method
 
+=head1 SYNOPSIS
+
+Using via L<Types::Standard>:
+
+  package Logger {
+    use Moo;
+    use Types::Standard qw( HasMethods Bool );
+    
+    has debugging => ( is => 'rw', isa => Bool, default => 0 );
+    has output    => ( is => 'ro', isa => HasMethods[ 'print' ] );
+    
+    sub warn {
+      my ( $self, $message ) = @_;
+      $self->output->print( "[WARNING] $message\n" );
+    }
+    
+    sub debug {
+      my ( $self, $message ) = @_;
+      $self->output->print( "[DEBUG] $message\n" ) if $self->debugging;
+    }
+  }
+
+Using Type::Tiny::Duck's export feature:
+
+  package Logger {
+    use Moo;
+    use Types::Standard qw( Bool );
+    use Type::Tiny::Duck Printable => [ 'print' ];
+    
+    has debugging => ( is => 'rw', isa => Bool, default => 0 );
+    has output    => ( is => 'ro', isa => Printable );
+    
+    sub warn {
+      my ( $self, $message ) = @_;
+      $self->output->print( "[WARNING] $message\n" );
+    }
+    
+    sub debug {
+      my ( $self, $message ) = @_;
+      $self->output->print( "[DEBUG] $message\n" ) if $self->debugging;
+    }
+  }
+
+Using Type::Tiny::Duck's object-oriented interface:
+
+  package Logger {
+    use Moo;
+    use Types::Standard qw( Bool );
+    use Type::Tiny::Duck;
+    
+    my $Printable = Type::Type::Duck->new(
+      name    => 'Printable',
+      methods => [ 'print' ],
+    );
+    
+    has debugging => ( is => 'rw', isa => Bool, default => 0 );
+    has output    => ( is => 'ro', isa => $Printable );
+    
+    sub warn {
+      my ( $self, $message ) = @_;
+      $self->output->print( "[WARNING] $message\n" );
+    }
+    
+    sub debug {
+      my ( $self, $message ) = @_;
+      $self->output->print( "[DEBUG] $message\n" ) if $self->debugging;
+    }
+  }
+
 =head1 STATUS
 
 This module is covered by the
@@ -186,6 +259,11 @@ L<Type-Tiny stability policy|Type::Tiny::Manual::Policies/"STABILITY">.
 
 Type constraints of the general form C<< { $_->can("method") } >>.
 
+The name refers to the saying, "If it looks like a duck, swims like a duck,
+and quacks like a duck, then it probably is a duck". Duck typing can be
+a more flexible way of testing objects than relying on C<isa>, as it allows
+people to easily substitute mock objects.
+
 This package inherits from L<Type::Tiny>; see that for most documentation.
 Major differences are listed below:
 
@@ -278,7 +356,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014, 2017-2022 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2017-2025 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
