@@ -8,7 +8,7 @@ use warnings;
 
 BEGIN {
 	$Types::Standard::ArrayRef::AUTHORITY = 'cpan:TOBYINK';
-	$Types::Standard::ArrayRef::VERSION   = '2.000001';
+	$Types::Standard::ArrayRef::VERSION   = '2.008003';
 }
 
 $Types::Standard::ArrayRef::VERSION =~ tr/_//d;
@@ -19,11 +19,40 @@ use Types::TypeTiny ();
 
 sub _croak ($;@) { require Error::TypeTiny; goto \&Error::TypeTiny::croak }
 
+use Exporter::Tiny 1.004001 ();
+our @ISA = qw( Exporter::Tiny );
+
+sub _exporter_fail {
+	my ( $class, $type_name, $values, $globals ) = @_;
+	my $caller = $globals->{into};
+	
+	my $of = exists( $values->{of} ) ? $values->{of} : $values->{type};
+	defined $of or _croak( qq{Expected option "of" for type "$type_name"} );
+	if ( not Types::TypeTiny::is_TypeTiny($of) ) {
+		require Type::Utils;
+		$of = Type::Utils::dwim_type( $of, for => $caller );
+	}
+	
+	my $type = Types::Standard::ArrayRef->of( $of );
+	$type = $type->create_child_type(
+		name => $type_name,
+		$type->has_coercion ? ( coercion => 1 ) : (),
+		exists( $values->{where} ) ? ( constraint => $values->{where} ) : (),
+	);
+	
+	$INC{'Type/Registry.pm'}
+		? 'Type::Registry'->for_class( $caller )->add_type( $type, $type_name )
+		: ( $Type::Registry::DELAYED{$caller}{$type_name} = $type )
+		unless( ref($caller) or $caller eq '-lexical' or $globals->{'lexical'} );
+	return map +( $_->{name} => $_->{code} ), @{ $type->exportables };
+}
+
 no warnings;
 
 sub __constraint_generator {
 	return Types::Standard::ArrayRef unless @_;
 	
+	Type::Tiny::check_parameter_count_for_parameterized_type( 'Types::Standard', 'ArrayRef', \@_, 3 );
 	my $param = shift;
 	Types::TypeTiny::is_TypeTiny( $param )
 		or _croak(
@@ -204,3 +233,98 @@ sub __coercion_generator {
 } #/ sub __coercion_generator
 
 1;
+
+__END__
+
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Types::Standard::ArrayRef - exporter utility for the B<ArrayRef> type constraint
+
+=head1 SYNOPSIS
+
+  use Types::Standard -types;
+  
+  # Normal way to validate an arrayref of integers.
+  #
+  ArrayRef->of( Int )->assert_valid( [ 1, 2, 3 ] );
+  
+  use Types::Standard::ArrayRef Ints => { of => Int },
+  
+  # Exported shortcut
+  #
+  assert_Ints [ 1, 2, 3 ];
+
+=head1 STATUS
+
+This module is not covered by the
+L<Type-Tiny stability policy|Type::Tiny::Manual::Policies/"STABILITY">.
+
+=head1 DESCRIPTION
+
+This is mostly internal code, but can also act as an exporter utility.
+
+=head2 Exports
+
+Types::Standard::ArrayRef can be used experimentally as an exporter.
+
+  use Types::Standard 'Int';
+  use Types::Standard::ArrayRef Ints => { of => Int };
+
+This will export the following functions into your namespace:
+
+=over
+
+=item C<< Ints >>
+
+=item C<< is_Ints( $value ) >>
+
+=item C<< assert_Ints( $value ) >>
+
+=item C<< to_Ints( $value ) >>
+
+=back
+
+Multiple types can be exported at once:
+
+  use Types::Standard -types;
+  use Types::Standard::ArrayRef (
+    Ints   => { of => Int },
+    Nums   => { of => Num },
+    Strs   => { of => Str },
+  );
+  
+  assert_Ints [ 1, 2, 3 ];   # should not die
+
+It's possible to further constrain the arrayref using C<where>:
+
+  use Types::Standard::ArrayRef Ints => { of => Int, where => sub { ... } };
+
+=head1 BUGS
+
+Please report any bugs to
+L<https://github.com/tobyink/p5-type-tiny/issues>.
+
+=head1 SEE ALSO
+
+L<Types::Standard>.
+
+=head1 AUTHOR
+
+Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2013-2025 by Toby Inkster.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
